@@ -6,11 +6,11 @@ bp = Blueprint('site', __name__)
 
 @bp.route('/')
 def index():
-    """首页"""
-    return render_template('site/index.html')
+    """Index page."""
+    return render_template('site/index/index.html')
 
 
 @bp.route('/about')
 def about():
-    """关于页"""
-    return render_template('site/about.html')
\ No newline at end of file
+    """About page."""
+    return render_template('site/about/about.html')
