@@ -8,13 +8,13 @@ class User(db.Model):
     id = db.Column(db.Integer, primary_key=True)
     name = db.Column(db.String(50), unique=True)
     email = db.Column(db.String(50), unique=True)
-    avatar = db.Column(db.String(200))
+    avatar = db.Column(db.String(200), default='default.png')
     password = db.Column(db.String(200))
     is_admin = db.Column(db.Boolean, default=False)
     created_at = db.Column(db.DateTime, default=datetime.now)
 
     def __setattr__(self, name, value):
-        # 每当设置password时，自动进行hash
+        # Hash password when set it.
         if name == 'password':
             value = generate_password_hash(value)
         super(User, self).__setattr__(name, value)
