@@ -3,7 +3,7 @@ import os
 
 
 def load_config():
-    """加载配置类"""
+    """Load config."""
     mode = os.environ.get('MODE')
     try:
         if mode == 'PRODUCTION':
@@ -15,6 +15,6 @@ def load_config():
         else:
             from .development import DevelopmentConfig
             return DevelopmentConfig
-    except ImportError, e:
+    except ImportError:
         from .default import Config
         return Config
\ No newline at end of file
