@@ -3,7 +3,7 @@ import os
 
 
 class Config(object):
-    """配置基类"""
+    """Base config class."""
     # Flask app config
     DEBUG = False
     TESTING = False
@@ -22,23 +22,8 @@ class Config(object):
     # See:
     # https://pythonhosted.org/Flask-SQLAlchemy/config.html#connection-uri-format
     # http://docs.sqlalchemy.org/en/rel_0_9/core/engines.html#database-urls
-    SQLALCHEMY_DATABASE_URI = "mysql://user:password@host/database"
-
-    # SMTP config
-    SMTP_HOST = ""  # SMTP服务器
-    SMTP_PORT = 25
-    SMTP_USER = ""  # 用户名
-    SMTP_PASSWORD = ""  # 口令
-
-    # Redis
-    REDIS = False  # 是否启用Redis
-    REDIS_HOST = "localhost"
-    REDIS_PORT = 6379
-    REDIS_DB = 1
-
-    # Uploadsets config
-    UPLOADS_DEFAULT_DEST = "%s/uploads" % PROJECT_PATH  # 上传文件存储路径
-    UPLOADS_DEFAULT_URL = "%s/uploads/" % SITE_DOMAIN  # 上传文件访问URL
+    SQLALCHEMY_DATABASE_URI = "mysql+pymysql://user:password@host/database"
+    SQLALCHEMY_TRACK_MODIFICATIONS = False
 
     # Flask-DebugToolbar
     DEBUG_TB_INTERCEPT_REDIRECTS = False
