@@ -7,5 +7,4 @@ class DevelopmentConfig(Config):
     DEBUG = True
 
     # SQLAlchemy config
-    # 如果是空密码，则直接将password删除即可
-    SQLALCHEMY_DATABASE_URI = "mysql://root:@localhost/boost"
+    SQLALCHEMY_DATABASE_URI = "mysql+pymysql://root:@localhost/flask-boost"
