@@ -1,5 +1,5 @@
 # coding: utf-8
-from fabric.api import run, env, cd, prefix, shell_env
+from fabric.api import run, env, cd, prefix, shell_env, local
 from config import load_config
 
 config = load_config()
@@ -7,28 +7,20 @@ host_string = config.HOST_STRING
 
 
 def deploy():
-    """部署"""
     env.host_string = config.HOST_STRING
     with cd('/var/www/#{project}'):
         with shell_env(MODE='PRODUCTION'):
             run('git reset --hard HEAD')
             run('git pull')
+            run('npm install')
+            run('gulp')
             with prefix('source venv/bin/activate'):
                 run('pip install -r requirements.txt')
                 run('python manage.py db upgrade')
+                run('python manage.py build')
             run('supervisorctl restart #{project}')
 
 
-def pull():
-    """更新代码"""
-    env.host_string = config.HOST_STRING
-    with cd('/var/www/#{project}'):
-        with shell_env(MODE='PRODUCTION'):
-            run('git reset --hard HEAD')
-            run('git pull')
-
-
 def restart():
-    """重启"""
     env.host_string = config.HOST_STRING
-    run('supervisorctl restart #{project}')
\ No newline at end of file
+    run('supervisorctl restart #{project}')
