@@ -1,4 +1,6 @@
 # coding: utf-8
+import os
+import glob2
 from flask.ext.script import Manager
 from flask.ext.migrate import Migrate, MigrateCommand
 from application import create_app
@@ -25,31 +27,22 @@ def run():
 def live():
     """Run livereload server"""
     from livereload import Server
-    import formic
 
     server = Server(app)
 
-    # css
-    for filepath in formic.FileSet(include="application/static/css/**/*.css"):
-        server.watch(filepath)
-    # html
-    for filepath in formic.FileSet(include="application/templates/css/**/*.html"):
-        server.watch(filepath)
-    # js
-    for filepath in formic.FileSet(include="application/static/js/**/*.js"):
-        server.watch(filepath)
-    # image
-    for filepath in formic.FileSet(include="application/static/image/**/*.*"):
-        server.watch(filepath)
+    map(server.watch, glob2.glob("application/pages/**/*.*"))  # pages
+    map(server.watch, glob2.glob("application/macros/**/*.html"))  # macros
+    map(server.watch, glob2.glob("application/static/**/*.*"))  # public assets
 
     server.serve(port=PORT)
 
 
 @manager.command
-def createdb():
-    """Create database."""
-    db.create_all()
+def build():
+    """Use FIS to compile assets."""
+    os.chdir('application')
+    os.system('fis release -d ../output -opmD')
 
 
 if __name__ == "__main__":
-    manager.run()
\ No newline at end of file
+    manager.run()
